==> lxqt-panel-2.0.0.tar.xz: lxqt-panel-2.0.0/plugin-fancymenu/translations/fancymenu_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>LXQtFancyMenu</name>
    <message>
        <location filename="../lxqtfancymenu.cpp" line="93"/>
        <source>Show/hide main menu</source>
        <translation>Mostrar/ocultar el menú principal</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuAppMapStrings</name>
    <message>
        <location filename="../lxqtfancymenuappmap.cpp" line="49"/>
        <source>Favorites</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuappmap.cpp" line="55"/>
        <source>All Applications</source>
        <translation>Todas las aplicaciones</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuConfiguration</name>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="14"/>
        <source>Fancy Menu settings</source>
        <translation>Configuración del menú elegante</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation>Icono:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation>Texto del botón:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation>Tamaño de fuente personalizado:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translation> pt</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="99"/>
        <source>Auto-select after:</source>
        <translation>Seleccionar automáticamente después de:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="109"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="134"/>
        <source>Menu file</source>
        <translation>Archivo de menú</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="140"/>
        <source>Menu file:</source>
        <translation>Archivo de menú:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="156"/>
        <source>Keyboard Shortcut</source>
        <translation>Atajo de teclado</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="175"/>
        <source>Click the button to record shortcut:</source>
        <translation>Presione el botón para registrar el atajo:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="185"/>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="191"/>
        <source>Clear search upon showing menu</source>
        <translation>Borrar la búsqueda al cerrar el menú</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="201"/>
        <source>Layout</source>
        <translation>Disposición</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="210"/>
        <source>Buttons row position</source>
        <translation>Posición de la fila de botones</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="217"/>
        <source>Categories position</source>
        <translation>Posición de las categorías</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="81"/>
        <source>Reset</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="111"/>
        <source>Bottom</source>
        <translation>Abajo</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="112"/>
        <source>Top</source>
        <translation>Arriba</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="117"/>
        <source>Left</source>
        <translation>Izquierda</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="118"/>
        <source>Right</source>
        <translation>Derecha</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="179"/>
        <source>Choose icon file</source>
        <translation>Elija un archivo de icono</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="181"/>
        <source>Images (*.svg *.png)</source>
        <translation>Imágenes (*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="193"/>
        <source>Choose menu file</source>
        <translation>Escoja un archivo de menú</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="195"/>
        <source>Menu files (*.menu)</source>
        <translation>Archivos de menú (*.menu)</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuWindow</name>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="153"/>
        <source>Search...</source>
        <translation>Buscar...</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="160"/>
        <source>LXQt Configuration Center</source>
        <translation>Centro de configuración de LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="166"/>
        <source>Leave</source>
        <translation>Salir</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="172"/>
        <source>About LXQt</source>
        <translation>Acerca de LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="185"/>
        <source>Add your favorites by right clicking items from categories.</source>
        <translation>Agregue sus favoritos haciendo clic derecho en los elementos de las categorías.</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="345"/>
        <source>Add to desktop</source>
        <translation>Añadir al escritorio</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="353"/>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="354"/>
        <source>A file with the same name already exists.
Do you want to overwrite it?</source>
        <translation>Ya existe un archivo con el mismo nombre.
¿Quiere sobrescribirlo?</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="360"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="361"/>
        <source>The file cannot be overwritten.</source>
        <translation>El archivo no puede ser sobrescrito.</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="368"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="381"/>
        <source>Remove from Favorites</source>
        <translation>Quitar de Favoritos</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="388"/>
        <source>Add to Favorites</source>
        <translation>Agregar a los favoritos</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="572"/>
        <source>No Executable</source>
        <translation>No Ejecutable</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="573"/>
        <source>Cannot find &lt;b&gt;%1&lt;/b&gt; executable.</source>
        <translation>No se puede encontrar el ejecutable &lt;b&gt;%1&lt;/b&gt;.</translation>
    </message>
</context>
</TS>

==> lxqt-panel-2.1.1.tar.xz: lxqt-panel-2.1.1/plugin-fancymenu/translations/fancymenu_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>LXQtFancyMenu</name>
    <message>
        <location filename="../lxqtfancymenu.cpp" line="93"/>
        <source>Show/hide main menu</source>
        <translation>Mostrar/ocultar el menú principal</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuAppMapStrings</name>
    <message>
        <location filename="../lxqtfancymenuappmap.cpp" line="49"/>
        <source>Favorites</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuappmap.cpp" line="56"/>
        <source>All Applications</source>
        <translation>Todas las aplicaciones</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuConfiguration</name>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="14"/>
        <source>Fancy Menu Settings</source>
        <translation>Configuración del menú elegante</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation>Icono:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation>Texto del botón:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation>Tamaño de fuente personalizado:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translation> pt</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="99"/>
        <source>Auto-select after:</source>
        <translation>Seleccionar automáticamente después de:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="109"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="134"/>
        <source>Menu file</source>
        <translation>Archivo de menú</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="140"/>
        <source>Menu file:</source>
        <translation>Archivo de menú:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="156"/>
        <source>Keyboard Shortcut</source>
        <translation>Atajo de teclado</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="175"/>
        <source>Click the button to record shortcut:</source>
        <translation>Presione el botón para registrar el atajo:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="185"/>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="191"/>
        <source>Clear search upon showing menu</source>
        <translation>Borrar la búsqueda al cerrar el menú</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="201"/>
        <source>Layout</source>
        <translation>Disposición</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="210"/>
        <source>Buttons row position</source>
        <translation>Posición de la fila de botones</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="217"/>
        <source>Categories position</source>
        <translation>Posición de las categorías</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="81"/>
        <source>Reset</source>
        <translation>Restablecer</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="111"/>
        <source>Bottom</source>
        <translation>Abajo</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="112"/>
        <source>Top</source>
        <translation>Arriba</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="117"/>
        <source>Left</source>
        <translation>Izquierda</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="118"/>
        <source>Right</source>
        <translation>Derecha</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="179"/>
        <source>Choose icon file</source>
        <translation>Elija un archivo de icono</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="181"/>
        <source>Images (*.svg *.png)</source>
        <translation>Imágenes (*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="193"/>
        <source>Choose menu file</source>
        <translation>Escoja un archivo de menú</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="195"/>
        <source>Menu files (*.menu)</source>
        <translation>Archivos de menú (*.menu)</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuWindow</name>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="155"/>
        <source>Search...</source>
        <translation>Buscar...</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="161"/>
        <source>LXQt Configuration Center</source>
        <translation>Centro de configuración de LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="167"/>
        <source>Leave</source>
        <translation>Salir</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="173"/>
        <source>About LXQt</source>
        <translation>Acerca de LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="191"/>
        <source>Add your favorites by right clicking items from categories.</source>
        <translation>Agregue sus favoritos haciendo clic derecho en los elementos de las categorías.</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="357"/>
        <source>Add to desktop</source>
        <translation>Añadir al escritorio</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="365"/>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="366"/>
        <source>A file with the same name already exists.
Do you want to overwrite it?</source>
        <translation>Ya existe un archivo con el mismo nombre.
¿Quiere sobrescribirlo?</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="372"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="373"/>
        <source>The file cannot be overwritten.</source>
        <translation>El archivo no puede sobrescribirse.</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="380"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="393"/>
        <source>Remove from Favorites</source>
        <translation>Quitar de Favoritos</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="400"/>
        <source>Add to Favorites</source>
        <translation>Agregar a los favoritos</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="716"/>
        <source>No Executable</source>
        <translation>Ningún ejecutable</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="717"/>
        <source>Cannot find &lt;b&gt;%1&lt;/b&gt; executable.</source>
        <translation>No se puede encontrar el ejecutable &lt;b&gt;%1&lt;/b&gt;.</translation>
    </message>
</context>
</TS>
